@@ -8,19 +8,29 @@ from pathlib import Path
 from google.cloud import storage
 
 
-def file_handler(config):
+def file_handler(config, api_run, start_date, end_date):
 
     run_id = datetime.datetime.now().strftime("%Y-%m-%d-%H-%M-%S.%f")
 
-    user_output_path = ast.literal_eval(config["user_settings"]["output_path"])
+    start_date_string = datetime.datetime.strptime(start_date, "%Y-%m-%d").strftime(
+        "%B-%d-%Y"
+    )
+    end_date_string = datetime.datetime.strptime(end_date, "%Y-%m-%d").strftime(
+        "%B-%d-%Y"
+    )
+
+    if api_run:
+        user_output_path = config["user_settings"]["output_path"].strip("\"'")
+    else:
+        user_output_path = ast.literal_eval(config["user_settings"]["output_path"])
 
     if not user_output_path:
         raise ValueError("Please provide a valid output directory.")
 
-    run_id_path_data = f"{user_output_path}/output_data/{run_id}/data/"
-    run_id_path_metadata = f"{user_output_path}/output_data/{run_id}/metadata/"
-    run_id_path_report = f"{user_output_path}/output_data/{run_id}/report/"
-    run_id_path = f"{user_output_path}/output_data/{run_id}/"
+    run_id_path_data = f"{user_output_path}/output_data/{run_id}_{start_date_string}_to_{end_date_string}/data/"
+    run_id_path_metadata = f"{user_output_path}/output_data/{run_id}_{start_date_string}_to_{end_date_string}/metadata/"
+    run_id_path_report = f"{user_output_path}/output_data/{run_id}_{start_date_string}_to_{end_date_string}/report/"
+    run_id_path = f"{user_output_path}/output_data/{run_id}_{start_date_string}_to_{end_date_string}/"
 
     data_path = Path(run_id_path_data)
     metadata_path = Path(run_id_path_metadata)
@@ -60,7 +70,7 @@ def gcp_upload_from_directory(
     gcp_credentials: str,
 ):
 
-    os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = gcp_credentials
+    os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = gcp_credentials.strip("\"'")
     storage_client = storage.Client()
     bucket = storage_client.get_bucket(destination_bucket_name)
     local_paths = glob.glob(directory_path + "/**", recursive=True)
